@@ -23,6 +23,9 @@ get_rendered_template_string = (
 
 
 class EmailMessageManager(models.Manager):
+    def get_queryset(self) -> models.QuerySet["EmailMessage"]:
+        return models.QuerySet(self.model, using=self._db)
+
     @atomic
     def reset_messages(self) -> None:
         """
@@ -34,7 +37,7 @@ class EmailMessageManager(models.Manager):
             .update(status=EmailMessage.Statuses.new)
 
     @atomic
-    def choose_to_send(self, quantity: int) -> models.QuerySet['EmailMessage']:
+    def choose_to_send(self, quantity: int) -> models.QuerySet["EmailMessage"]:
         sending_messages = self.filter(
             status=EmailMessage.Statuses.new,
             send_time__lte=now()
